pub struct AbTestSuite {
pub comparisons: Vec<QualityComparison>,
}Expand description
A suite of A/B comparisons that can identify the overall best candidate.
Fields
comparisons: Vec<QualityComparison>All comparisons in this suite.
Implementations
Sourceimpl AbTestSuite
impl AbTestSuite
Sourcepub fn add(&mut self, comparison: QualityComparison)
pub fn add(&mut self, comparison: QualityComparison)
Adds a comparison to the suite.
Sourcepub fn comparison_count(&self) -> usize
pub fn comparison_count(&self) -> usize
Returns the number of comparisons in the suite.
Sourcepub fn best_candidate_by_psnr(&self) -> Option<String>
pub fn best_candidate_by_psnr(&self) -> Option<String>
Returns the name of the candidate that wins the most comparisons by PSNR.
Returns None if the suite is empty.
Sourcepub fn best_candidate_by_efficiency(&self) -> Option<String>
pub fn best_candidate_by_efficiency(&self) -> Option<String>
Returns the name of the candidate that wins the most comparisons by efficiency.
Returns None if the suite is empty.