pub struct BandwidthEstimator { /* private fields */ }Expand description
Ring buffer of recent bandwidth samples (last 30 samples).
Implementations
Sourceimpl BandwidthEstimator
impl BandwidthEstimator
Sourcepub fn add_sample(&mut self, point: BandwidthPoint)
pub fn add_sample(&mut self, point: BandwidthPoint)
Adds a bandwidth sample, evicting oldest if at capacity.
Sourcepub fn sample_count(&self) -> usize
pub fn sample_count(&self) -> usize
Returns the number of samples in the buffer.
Sourcepub fn estimated_kbps(&self) -> Option<u32>
pub fn estimated_kbps(&self) -> Option<u32>
Returns the estimated bandwidth as the average of recent samples.
Sourcepub fn samples(&self) -> &VecDeque<BandwidthPoint>
pub fn samples(&self) -> &VecDeque<BandwidthPoint>
Returns all samples in the buffer.