pub struct AudioTranscodeParams {
pub input_layout: AudioLayout,
pub output_layout: AudioLayout,
pub input_sample_rate: u32,
pub output_sample_rate: u32,
pub target_bitrate_bps: u32,
pub gain_linear: f32,
pub normalise_loudness: bool,
}Expand description
Parameters that govern how a single audio stream is transcoded.
Fields
input_layout: AudioLayoutInput channel layout.
output_layout: AudioLayoutDesired output channel layout.
input_sample_rate: u32Input sample rate in Hz.
output_sample_rate: u32Desired output sample rate in Hz.
target_bitrate_bps: u32Target audio bitrate in bits per second.
gain_linear: f32Linear gain to apply during transcode (1.0 = no change).
normalise_loudness: boolWhether to normalise loudness to EBU R128.
Implementations
Sourceimpl AudioTranscodeParams
impl AudioTranscodeParams
Sourcepub fn mono_downmix() -> Self
pub fn mono_downmix() -> Self
Create params for a mono downmix.
Sourcepub fn is_passthrough(&self) -> bool
pub fn is_passthrough(&self) -> bool
Returns true when the output layout and sample rate match the input
and no gain or loudness normalisation is applied — i.e. pure passthrough.