pub struct SubtitleEntry {
pub text: String,
pub start_ms: u64,
pub end_ms: u64,
pub anchor: SubtitleAnchor,
pub font: Option<SubtitleFont>,
pub margin_px: u32,
}Expand description
A single subtitle entry with text, timing, and style.
Fields
text: StringSubtitle text (may contain newlines for multi-line).
start_ms: u64Start time in milliseconds.
end_ms: u64End time in milliseconds.
anchor: SubtitleAnchorPosition anchor.
font: Option<SubtitleFont>Font style override (uses config default if None).
margin_px: u32Margin from the frame edge in pixels.
Implementations
Sourceimpl SubtitleEntry
impl SubtitleEntry
Sourcepub fn new(text: impl Into<String>, start_ms: u64, end_ms: u64) -> Self
pub fn new(text: impl Into<String>, start_ms: u64, end_ms: u64) -> Self
Creates a new subtitle entry.
Sourcepub fn with_anchor(self, anchor: SubtitleAnchor) -> Self
pub fn with_anchor(self, anchor: SubtitleAnchor) -> Self
Sets the position anchor.
Sourcepub fn with_font(self, font: SubtitleFont) -> Self
pub fn with_font(self, font: SubtitleFont) -> Self
Sets a font override for this entry.
Sourcepub fn duration_ms(&self) -> u64
pub fn duration_ms(&self) -> u64
Returns the duration of this subtitle entry in milliseconds.
Sourcepub fn is_active_at(&self, timestamp_ms: u64) -> bool
pub fn is_active_at(&self, timestamp_ms: u64) -> bool
Returns true if this subtitle is active at the given timestamp.