pub struct ResolvedTrimRange {
pub in_point: FrameTimecode,
pub out_point: FrameTimecode,
}Expand description
A TrimRange whose points have been resolved to concrete FrameTimecode values.
Fields
in_point: FrameTimecodeResolved in-point.
out_point: FrameTimecodeResolved out-point.
Implementations
Sourceimpl ResolvedTrimRange
impl ResolvedTrimRange
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Returns the duration in frames (inclusive).
Sourcepub fn duration_ms(&self) -> u64
pub fn duration_ms(&self) -> u64
Returns the duration in milliseconds.
Sourcepub fn contains_frame(&self, frame: u64) -> bool
pub fn contains_frame(&self, frame: u64) -> bool
Returns true if frame falls within this trim range (inclusive).