pub struct SceneSegment {
pub start_frame: u64,
pub end_frame: u64,
pub duration_frames: u32,
pub motion_score: f32,
pub complexity: f32,
pub is_dark: bool,
pub scene_type: SceneType,
}Expand description
A contiguous segment of frames identified as a distinct scene.
Fields
start_frame: u64Index of the first frame (inclusive).
end_frame: u64Index of the last frame (inclusive).
duration_frames: u32Number of frames in this segment.
motion_score: f32Normalised motion score in [0.0, 1.0].
complexity: f32Normalised spatial complexity in [0.0, 1.0].
is_dark: boolWhether the scene is predominantly dark (low average luma).
scene_type: SceneTypeContent-type classification.
Implementations
Sourceimpl SceneSegment
impl SceneSegment
Sourcepub fn new(
start_frame: u64,
end_frame: u64,
duration_frames: u32,
motion_score: f32,
complexity: f32,
is_dark: bool,
scene_type: SceneType,
) -> Self
pub fn new( start_frame: u64, end_frame: u64, duration_frames: u32, motion_score: f32, complexity: f32, is_dark: bool, scene_type: SceneType, ) -> Self
Constructs a new SceneSegment with explicit fields.
Sourcepub fn frame_count(&self) -> u32
pub fn frame_count(&self) -> u32
Returns the number of frames (alias for clarity).
Sourcepub fn duration_secs(&self, fps: f32) -> f32
pub fn duration_secs(&self, fps: f32) -> f32
Returns the duration in seconds at the given frame rate.