pub enum LadderValidationError {
TooFewRungs {
count: usize,
},
DuplicateHeight {
height: u32,
},
NonMonotonicBitrate {
index: usize,
bitrate: u32,
prev_bitrate: u32,
},
NonMonotonicHeight {
index: usize,
height: u32,
prev_height: u32,
},
}Expand description
Validation errors for a ladder specification.
Variants
TooFewRungs
Fewer than two rungs.
DuplicateHeight
A rung has the same height as another.
NonMonotonicBitrate
Bitrates are not strictly decreasing from top to bottom.
Fields
NonMonotonicHeight
Heights are not strictly decreasing from top to bottom.