pub struct LadderValidator;Expand description
Validates a LadderSpec for structural correctness.
Implementations
Sourceimpl LadderValidator
impl LadderValidator
Sourcepub fn validate(&self, spec: &LadderSpec) -> Vec<LadderValidationError>
pub fn validate(&self, spec: &LadderSpec) -> Vec<LadderValidationError>
Validates spec, returning a list of all errors found.
An empty list means the ladder is valid.
Sourcepub fn is_valid(&self, spec: &LadderSpec) -> bool
pub fn is_valid(&self, spec: &LadderSpec) -> bool
Returns true if the ladder passes all validation checks.