pub struct TranscodeSessionManager { /* private fields */ }Expand description
Manages a collection of transcode sessions.
Implementations
Sourceimpl TranscodeSessionManager
impl TranscodeSessionManager
Sourcepub fn create(
&mut self,
input_path: impl Into<String>,
output_path: impl Into<String>,
total_duration_ms: u64,
) -> u64
pub fn create( &mut self, input_path: impl Into<String>, output_path: impl Into<String>, total_duration_ms: u64, ) -> u64
Creates a new session and registers it. Returns the session ID.
Sourcepub fn get(&self, id: u64) -> Option<&TranscodeSession>
pub fn get(&self, id: u64) -> Option<&TranscodeSession>
Returns a reference to the session with the given ID, if it exists.
Sourcepub fn get_mut(&mut self, id: u64) -> Option<&mut TranscodeSession>
pub fn get_mut(&mut self, id: u64) -> Option<&mut TranscodeSession>
Returns a mutable reference to the session with the given ID.
Sourcepub fn active_count(&self) -> usize
pub fn active_count(&self) -> usize
Returns the number of currently active (Running) sessions.
Sourcepub fn total_count(&self) -> usize
pub fn total_count(&self) -> usize
Returns the total number of sessions tracked.
Sourcepub fn sessions_in_state(&self, state: SessionState) -> Vec<u64>
pub fn sessions_in_state(&self, state: SessionState) -> Vec<u64>
Returns IDs of all sessions in a given state.