pub struct OutputValidator;Expand description
Output configuration validator.
Implementations
Sourceimpl OutputValidator
impl OutputValidator
Sourcepub fn validate_path(path: &str, overwrite: bool) -> Result<(), ValidationError>
pub fn validate_path(path: &str, overwrite: bool) -> Result<(), ValidationError>
Validates an output file path.
Errors
Returns an error if the output path is invalid or not writable.
Sourcepub fn validate_format(path: &str) -> Result<String, ValidationError>
pub fn validate_format(path: &str) -> Result<String, ValidationError>
Validates output format based on file extension.
Errors
Returns an error if the format is not supported.
Sourcepub fn validate_codec(codec: &str) -> Result<(), ValidationError>
pub fn validate_codec(codec: &str) -> Result<(), ValidationError>
Sourcepub fn validate_resolution(
width: u32,
height: u32,
) -> Result<(), ValidationError>
pub fn validate_resolution( width: u32, height: u32, ) -> Result<(), ValidationError>
Sourcepub fn validate_bitrate(
bitrate: u64,
min: u64,
max: u64,
) -> Result<(), ValidationError>
pub fn validate_bitrate( bitrate: u64, min: u64, max: u64, ) -> Result<(), ValidationError>
Sourcepub fn validate_frame_rate(num: u32, den: u32) -> Result<(), ValidationError>
pub fn validate_frame_rate(num: u32, den: u32) -> Result<(), ValidationError>