pub enum OutputLocation {
Fixed(PathBuf),
SiblingWithExtension(String),
DoneSubDir,
}Expand description
Policy for selecting the output directory of each transcode job.
Variants
Fixed(PathBuf)
Place output in a fixed directory.
SiblingWithExtension(String)
Place output next to the input, using the same name with a new extension.
DoneSubDir
Place output in a done/ sub-directory of the watch folder.