pub struct WatchFolderStats {
pub processed_count: u64,
pub error_count: u64,
pub total_processing_time_ms: u64,
pub total_bytes_processed: u64,
pub min_processing_time_ms: Option<u64>,
pub max_processing_time_ms: Option<u64>,
}Expand description
Statistics for a watch folder’s processing activity.
Fields
processed_count: u64Total number of files processed successfully.
error_count: u64Total number of files that failed processing.
total_processing_time_ms: u64Total processing time in milliseconds across all successful jobs.
total_bytes_processed: u64Total bytes processed (input file sizes).
min_processing_time_ms: Option<u64>Minimum processing time in milliseconds.
max_processing_time_ms: Option<u64>Maximum processing time in milliseconds.
Implementations
Sourceimpl WatchFolderStats
impl WatchFolderStats
Sourcepub fn record_success(&mut self, processing_time_ms: u64, file_size_bytes: u64)
pub fn record_success(&mut self, processing_time_ms: u64, file_size_bytes: u64)
Records a successful processing event.
Sourcepub fn record_error(&mut self)
pub fn record_error(&mut self)
Records a failed processing event.
Sourcepub fn avg_processing_time_ms(&self) -> Option<u64>
pub fn avg_processing_time_ms(&self) -> Option<u64>
Returns the average processing time in milliseconds, or None if no files processed.
Sourcepub fn success_rate(&self) -> f64
pub fn success_rate(&self) -> f64
Returns the success rate as a fraction [0.0, 1.0].
Sourcepub fn avg_throughput_bps(&self) -> Option<f64>
pub fn avg_throughput_bps(&self) -> Option<f64>
Returns the average throughput in bytes per second, or None if no data.