pub struct OverlayPipeline { /* private fields */ }Expand description
Aggregate overlay pipeline that composes multiple watermarks.
Implementations
Sourceimpl OverlayPipeline
impl OverlayPipeline
Sourcepub fn new(width: u32, height: u32) -> Self
pub fn new(width: u32, height: u32) -> Self
Create a new overlay pipeline for a given frame size.
Sourcepub fn add_layer(&mut self, config: WatermarkConfig)
pub fn add_layer(&mut self, config: WatermarkConfig)
Add a watermark layer.
Sourcepub fn layer_count(&self) -> usize
pub fn layer_count(&self) -> usize
Return the number of layers.
Sourcepub fn visible_layers_at(&self, time_seconds: f64) -> Vec<&WatermarkConfig>
pub fn visible_layers_at(&self, time_seconds: f64) -> Vec<&WatermarkConfig>
Return layers that are visible at the given timestamp.
Sourcepub fn frame_size(&self) -> (u32, u32)
pub fn frame_size(&self) -> (u32, u32)
Return the configured frame dimensions.