pub struct Vp9Config { /* private fields */ }Expand description
VP9 specific configuration.
Implementations
Sourceimpl Vp9Config
impl Vp9Config
Sourcepub fn crf(crf_value: u8) -> Self
pub fn crf(crf_value: u8) -> Self
Creates a VP9 configuration in CRF (constant quality) mode.
CRF range for VP9 is 0–63; lower values produce higher quality. Typical values: 31 (good quality), 33 (balanced), 41 (lower quality).
Sourcepub fn tile_columns(self, columns: u8) -> Self
pub fn tile_columns(self, columns: u8) -> Self
Sets the tile columns for parallel encoding (0–6, value is log2 of column count).
Sourcepub fn with_tile_columns(self, cols: u8) -> Self
pub fn with_tile_columns(self, cols: u8) -> Self
Sets the tile columns for parallel encoding via builder pattern (0–6).
Sourcepub fn frame_parallel(self, enable: bool) -> Self
pub fn frame_parallel(self, enable: bool) -> Self
Sets the frame parallel encoding.
Sourcepub fn with_frame_parallel(self, enabled: bool) -> Self
pub fn with_frame_parallel(self, enabled: bool) -> Self
Enables or disables frame-parallel decoding hint via builder pattern.
Sourcepub fn auto_alt_ref(self, frames: u8) -> Self
pub fn auto_alt_ref(self, frames: u8) -> Self
Sets the auto alt reference frames.
Sourcepub fn lag_in_frames(self, lag: u32) -> Self
pub fn lag_in_frames(self, lag: u32) -> Self
Sets the lag in frames (0–25).
Larger values allow better quality at the cost of encoding latency.
Sourcepub fn with_lag_in_frames(self, frames: u8) -> Self
pub fn with_lag_in_frames(self, frames: u8) -> Self
Sets lag in frames via builder pattern (0–25).
Sourcepub fn with_row_mt(self, enabled: bool) -> Self
pub fn with_row_mt(self, enabled: bool) -> Self
Enables or disables row-based multi-threading via builder pattern.
Sourcepub fn screen_content() -> Self
pub fn screen_content() -> Self
Screen content encoding preset.
Optimised for screen recordings: fast cpu-used, tile columns for parallelism, and row-mt for throughput. Uses CRF 33 as a balanced starting point.
Sourcepub fn build(self) -> CodecConfig
pub fn build(self) -> CodecConfig
Converts to base codec config.