pub struct InputValidator;Expand description
Input file validator.
Implementations
Sourceimpl InputValidator
impl InputValidator
Sourcepub fn validate_path(path: &str) -> Result<(), ValidationError>
pub fn validate_path(path: &str) -> Result<(), ValidationError>
Validates an input file path.
Errors
Returns an error if the input file is invalid or inaccessible.
Sourcepub fn validate_format(path: &str) -> Result<String, ValidationError>
pub fn validate_format(path: &str) -> Result<String, ValidationError>
Validates input format based on file extension.
Errors
Returns an error if the format is not supported.
Sourcepub fn validate_streams(
has_video: bool,
has_audio: bool,
require_video: bool,
require_audio: bool,
) -> Result<(), ValidationError>
pub fn validate_streams( has_video: bool, has_audio: bool, require_video: bool, require_audio: bool, ) -> Result<(), ValidationError>
Validates that input has required streams.